@@ -4,9 +4,9 @@
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
 #include <X11/Xresource.h>
-#include <X11/extensions/randr.h>
-#include <X11/extensions/Xrandr.h>
 #include <X11/extensions/Xinerama.h>
+#include <X11/extensions/Xrandr.h>
+#include <X11/extensions/randr.h>
 #include <assert.h>
 #include <glib.h>
 #include <locale.h>
@@ -23,6 +23,11 @@ int screens_len;
 
 bool dunst_follow_errored = false;
 
+int randr_event_base = 0;
+
+static int randr_major_version = 0;
+static int randr_minor_version = 0;
+
 void randr_init();
 void randr_update();
 void xinerama_update();
@@ -59,7 +64,8 @@ static double get_xft_dpi_value()
         return dpi;
 }
 
-void init_screens() {
+void init_screens()
+{
         if (!settings.force_xinerama) {
                 randr_init();
                 randr_update();
@@ -80,8 +86,6 @@ void alloc_screen_ar(int n)
         screens_len = n;
 }
 
-int randr_event_base = 0;
-
 void randr_init()
 {
         int randr_error_base = 0;
@@ -89,23 +93,36 @@ void randr_init()
                 fprintf(stderr, "Could not initialize the RandR extension, falling back to single monitor mode.\n");
                 return;
         }
+        XRRQueryVersion(xctx.dpy, &randr_major_version, &randr_minor_version);
         XRRSelectInput(xctx.dpy, RootWindow(xctx.dpy, DefaultScreen(xctx.dpy)), RRScreenChangeNotifyMask);
 }
 
 void randr_update()
 {
-        int n;
-        XRRMonitorInfo *m = XRRGetMonitors(xctx.dpy, RootWindow(xctx.dpy, DefaultScreen(xctx.dpy)), true, &n);
-
-        if (m == NULL || n == -1) {
-                fprintf(stderr, "(RandR) Could not get screen info, falling back to single monitor mode\n");
+        if (randr_major_version < 1
+            || (randr_major_version == 1 && randr_minor_version < 5)) {
+                fprintf(stderr, "Server RandR version too low (%i.%i). Falling back to single monitor mode\n",
+                                randr_major_version,
+                                randr_minor_version);
                 screen_update_fallback();
                 return;
         }
 
+        int n = 0;
+        XRRMonitorInfo *m = XRRGetMonitors(xctx.dpy, RootWindow(xctx.dpy, DefaultScreen(xctx.dpy)), true, &n);
+
+        if (n < 1) {
+                fprintf(stderr, "Get monitors reported %i monitors, falling back to single monitor mode\n", n);
+                screen_update_fallback();
+                return;
+        }
+
+        assert(m);
+
         alloc_screen_ar(n);
 
         for (int i = 0; i < n; i++) {
+                screens[i].scr = i;
                 screens[i].dim.x = m[i].x;
                 screens[i].dim.y = m[i].y;
                 screens[i].dim.w = m[i].width;
@@ -141,6 +158,7 @@ void xinerama_update()
         alloc_screen_ar(n);
 
         for (int i = 0; i < n; i++) {
+                screens[i].scr = i;
                 screens[i].dim.x = info[i].x_org;
                 screens[i].dim.y = info[i].y_org;
                 screens[i].dim.h = info[i].height;
@@ -149,7 +167,6 @@ void xinerama_update()
         XFree(info);
 }
 
-
 void screen_update_fallback()
 {
         alloc_screen_ar(1);
@@ -162,7 +179,6 @@ void screen_update_fallback()
 
         screens[0].dim.w = DisplayWidth(xctx.dpy, screen);
         screens[0].dim.h = DisplayHeight(xctx.dpy, screen);
-
 }
 
 /*
@@ -195,9 +211,15 @@ screen_info *get_active_screen()
                         unsigned int dummy_ui;
                         Window dummy_win;
 
-                        XQueryPointer(xctx.dpy, root, &dummy_win,
-                                        &dummy_win, &x, &y, &dummy,
-                                        &dummy, &dummy_ui);
+                        XQueryPointer(xctx.dpy,
+                                      root,
+                                      &dummy_win,
+                                      &dummy_win,
+                                      &x,
+                                      &y,
+                                      &dummy,
+                                      &dummy,
+                                      &dummy_ui);
                 }
 
                 if (settings.f_mode == FOLLOW_KEYBOARD) {
@@ -263,11 +285,20 @@ static Window get_focused_window(void)
         Atom netactivewindow =
             XInternAtom(xctx.dpy, "_NET_ACTIVE_WINDOW", false);
 
-        XGetWindowProperty(xctx.dpy, root, netactivewindow, 0L,
-                           sizeof(Window), false, XA_WINDOW,
-                           &type, &format, &nitems, &bytes_after, &prop_return);
+        XGetWindowProperty(xctx.dpy,
+                           root,
+                           netactivewindow,
+                           0L,
+                           sizeof(Window),
+                           false,
+                           XA_WINDOW,
+                           &type,
+                           &format,
+                           &nitems,
+                           &bytes_after,
+                           &prop_return);
         if (prop_return) {
-                focused = *(Window *) prop_return;
+                focused = *(Window *)prop_return;
                 XFree(prop_return);
         }
 
@@ -290,7 +321,7 @@ static int x_follow_tear_down_error_handler(void)
         return dunst_follow_errored;
 }
 
-static int FollowXErrorHandler(Display * display, XErrorEvent * e)
+static int FollowXErrorHandler(Display *display, XErrorEvent *e)
 {
         dunst_follow_errored = true;
         char err_buf[BUFSIZ];
